@@ -1,7 +1,7 @@
 from django.conf import settings
 from django.db import models
+from django_jsonfield_backport.models import JSONField
 from .policy import policy_from_json
-from .fields import JSONField
 from .registry import ResourceType, register_access_controlled_model
 
 
@@ -23,7 +23,7 @@ class AccessControlledModel(IdentifiedByIRI, models.Model):
     Subclasses **MUST** define a `resource_type: ResourceType` property.
     """
 
-    rbac_context = models.CharField(max_length=2048, default="")
+    rbac_context = models.CharField(max_length=2048, default="", blank=True)
 
     class Meta:
         abstract = True
